.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Willkommen beim Sage Tutorial!
==============================

Sage ist eine freie, Open-Source-Software, die Forschung und
Lehre in Algebra, Geometrie, Zahlentheorie, Kryptographie, numerischen
Berechnungen und verwandten Gebieten unterstützt. Sowohl das
Entwicklungsmodell von Sage als auch die Technologie in Sage zeichnen
sich durch eine extrem starke Betonung von Offenheit, Gemeinschaft,
Kooperation und Zusammenarbeit aus. Wir bauen das Auto und erfinden
nicht das Rad neu. Das Ziel von Sage ist es, eine aktiv gepflegte,
freie Open-Source-Alternative zu Magma, Maple, Mathematica und Matlab
zu entwickeln.

Dieses Tutorial ist die beste Möglichkeit mit Sage in wenigen Stunden
vertraut zu werden. Sie können es im HTML- oder PDF-Format
lesen oder im Sage-Notebook. Dazu klicken Sie zuerst auf ``Help`` und
``Tutorial``, um innerhalb von Sage interaktiv mit dem
Tutorial zu arbeiten.

Diese Arbeit ist lizenziert unter einer  `Creative Commons Attribution-Share Alike
3.0 Lizenz`__.

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour
   interactive_shell
   interfaces
   latex
   programming
   sagetex
   afterword
   appendix
   bibliography

Indizes und Tabellen
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
